//
//	Includes
//
#include	"MCF52233.h"
#include	"ProtoType.h"

//
//	Constants
//
const UINT8 HexDigit[] = "0123456789abcdef";

//
//	Demo Thread
//
void PrintThread(void)
{
	TermPuts((UINT8*)"Thread executed\r\n");	// Show demo string
}

//
//	Memory dump sub
//
void DumpMemory(UINT8 *p)
{
UINT8 i;
	for(i = 0; i < 32; i++)
	{
		TermPutc(HexDigit[*p >> 4]);	// Put high 4 bit hex
		TermPutc(HexDigit[*p++ & 15]);	// Put low 4 bit hex	
		TermPutc(' ');	// Put space
	}
	TermPuts((UINT8*)"\r\n");	// Put CR+LF
}


//
//	main
//
void main(void)
{
UINT8		*p;	// Pointer work
UINT8		*f;	// Filename buffer
UINT8		i;	// Loop counter
UINT16	t;	// Timer value work	
UINT32	ip;	// IP address & file handle work
//
// Sample of
//   void *MemoryAlloc(UINT16 size);
//   void BufCopy(void *dst, void *src, UINT32 len);
//   void MemClear(void *ptr, UINT32 len);
//   void Sleep(UINT16 time);
//   void GetDigit(INT32 num, UINT8 *buf);
//   UINT8 *StrCat(UINT8 *x, UINT8 *y);
//   UINT8 *StrCpy(UINT8 *x, UINT8 *y);
//   void TermPuts(UINT8 *ptr);
//
	p = MemoryAlloc(32);	// Alloc 32 bytes
	BufCopy(p, (UINT8*)"This is a sample of BufCopy\r\n", 30);// Copy data
	TermPuts(p);		// Show result
	MemClear(p, 32);// Clear memory(32 bytes)

	for(i = 0; i < 5; i++)
	{
		GetDigit(i, p);	// Make digit string
		StrCat(p, (UINT8*)" ");	// Use StrCat library(add space)
		TermPuts(p);	// Show result
		Sleep(50);		// Wait 0.5 sec (50 x 10mS)		
	}
	StrCpy(p, (UINT8*)"\r\n");	// Use StrCpy to create CR+LF string
	TermPuts(p);	// Put CR+LF

//
// Sample of
//   UINT8 CreateTimer(UINT8 mode, CallbackFunc8 func,
//                           UINT16 val, UINT8 timer, UINT8 stack);
//   UINT16	GetTimerCount(UINT8 timer);
//   void TermPutNum(INT32 num);
//
	i = CreateTimer(1, 0, 300, 0, 0);	// Create simple timer
	for(;;)
	{
		t = GetTimerCount(i);	// Get timer value
		TermPutNum(t);				// Show timer value
		TermPuts((UINT8*)"  \r");	// Show blank tail & CR
		if(t == 0)	// End of count?
			break;		// Exit loop
	}

	(void)CreateTimer(0, 0, 0, i, 0);	// Release timer resource
// Create thread by timer(1 sec later)
	(void)CreateTimer(4, (void (*)(UINT8))PrintThread, 100, 0, 0);
	Sleep(200);		// Just wait 2 sec.

//
// Sample of UINT32	GetCgiIPadrs(UINT8 *ptr);
//   void TermPutIP(UINT32 ip);
//
	ip = GetCgiIPadrs((UINT8*)"192.168.1.10");// Get IP from string
	TermPutIP(ip);		// Show IP address
	TermPuts(p);	// Put CR+LF

//
// Sample of
//    void DefragFilesys(UINT16 key);
//    UINT8 CreateFile(UINT8 *filename);
//    UINT16 WriteFile(void *ptr, UINT16 size);
//    void CloseFile(UINT32 handle);
//    UINT8 DeleteFile(UINT8 *filename);
//    UINT8 MoveFile(UINT8 *filename, UINT8 *newfile);
//    UINT8	*FindFile(UINT8 init);
//    UINT32 GetFileSize(UINT8 *filename);
//    UINT32 OpenFile(UINT8 *filename);
//    UINT16 ReadFile(UINT32 handle, UINT8 *buf, UINT16 size);
//    UINT32 SeekFile(UINT32 fp, UINT32 pos, UINT8 org);
//
	DefragFilesys(0x4193);	// Defrag file system now(wait while)
	CreateFile((UINT8*)"TestFile");	// Create TestFile(write mode)	
	StrCpy(p, (UINT8*)"File Data\r\n");	// Setup string
	WriteFile(p, StrLen(p));	// Write string to file
	CloseFile(0);		// Close write mode file

	ip = GetFileSize((UINT8*)"TestFile");	// Get size of TestFile
	TermPuts((UINT8*)"FileSize=");	// Put CR+LF
	TermPutNum((INT32)ip);		// Show number
	TermPuts((UINT8*)"\r\n");	// Put CR+LF

	ip = OpenFile((UINT8*)"TestFile");
	MemClear(p, 32);	// Clear memory(32 bytes)

	ReadFile(ip, p, 5);		// Read 5 bytes
	TermPuts(p);			// Show read data
	TermPuts((UINT8*)"\r\n");	// Put CR+LF

	ReadFile(ip, p, 6);		// Read 6 bytes
	TermPuts(p);			// Show read data

	SeekFile(ip, SEEK_SET, 0);	// Seek to top
	ReadFile(ip, p, 11);		// Read 11 bytes
	TermPuts(p);			// Show read data

	CloseFile(ip);		// Close file and release file work memory
	MoveFile((UINT8*)"TestFile", (UINT8*)"TestFile2");	// Rename file
	DeleteFile((UINT8*)"TestFile2");
	Sleep(100);		// Wait 1 sec

	f = FindFile(1);	// Initialize find file
	while(f)	// Repeat while next file exists
	{
		TermPuts(f);	// Show filename
		TermPuts((UINT8*)"\r\n");	// Put CR+LF
		MemoryFree(f);		// Release filename buffer memory		
		f = FindFile(0);	// Search next file
	}
	Sleep(100);		// Wait 1 sec

// Sample of
//   UINT8 NvmWrite(UINT32 *ad, UINT32 *src, UINT16 size);
//   UINT8 NvmErase(UINT32 *ad);
	BufCopy(p, (UINT8*)0x2b000, 32);	// Get memory contents of 0x2b000
	DumpMemory(p);		// Dump memory

	for(i = 0; i < 32; i++)	// Repeat 32 bytes
		p[i] = i;	// Set seq number
	DisableInterrupts;
// Write flash memory 32 bytes
	NvmWrite((UINT32*)(0x2b000), (UINT32*)p, 32);
	EnableInterrupts;
	DumpMemory((UINT8*)0x2b000);		// Dump flash memory

	DisableInterrupts;
// Erase flash memory 2048 bytes
	NvmErase((UINT32*)(0x2b000));// Erase flash
	EnableInterrupts;
	DumpMemory((UINT8*)0x2b000);		// Dump flash memory

	MemoryFree(p);	// Release buffer
	UserExit(1);	// Notify user thread is over
}

